[−][src]Struct spirit_tokio::either::EitherDriver

pub struct EitherDriver<A, B> where
    A: Fragment,
    B: Fragment, 
{ /* fields omitted */ }

A Driver used for Either Fragments.

This switches between driving the variants ‒ if the fragment changes from one variant to another, the old driver is dropped and new one created for the other one. If the variant stays the same, driving is delegated to the existing driver.

Note that there are limitations to what this driver implementation ‒ see the Either drawbacks.