[−][src]Struct spirit_tokio::either::EitherInstaller

pub struct EitherInstaller<A, B>(_, _);

An Installer for Either Resources.

This wraps two distinct installers so it can install resources that are installable by one or the other.

Note that this to work, both installers need to exist at the same time (as opposed to the resource where one or the other is in existence).